@@ -66,9 +66,27 @@ eti.numeric <- function(x, ci = 0.95, verbose = TRUE, ...) {
 
 
 #' @export
-eti.data.frame <- function(x, ci = 0.95, verbose = TRUE, ...) {
+#' @rdname eti
+#' @inheritParams p_direction
+eti.data.frame <- function(x, ci = 0.95, rvar_col = NULL, verbose = TRUE, ...) {
+  obj_name <- insight::safe_deparse_symbol(substitute(x))
+
+  x_rvar <- .possibly_extract_rvar_col(x, rvar_col)
+  if (length(x_rvar) > 0L) {
+    cl <- match.call()
+    cl[[1]] <- bayestestR::eti
+    cl$x <- x_rvar
+    cl$rvar_col <- NULL
+    out <- eval.parent(cl)
+
+    attr(out, "object_name") <- sprintf('%s[["%s"]]', obj_name, rvar_col)
+
+    return(.append_datagrid(out, x, long = length(ci) > 1L))
+  }
+
+
   dat <- .compute_interval_dataframe(x = x, ci = ci, verbose = verbose, fun = "eti")
-  attr(dat, "object_name") <- insight::safe_deparse_symbol(substitute(x))
+  attr(dat, "object_name") <- obj_name
   dat
 }
 
@@ -174,8 +192,8 @@ eti.sim <- function(x, ci = 0.95, parameters = NULL, verbose = TRUE, ...) {
 #' @export
 eti.emmGrid <- function(x, ci = 0.95, verbose = TRUE, ...) {
   xdf <- insight::get_parameters(x)
-
   dat <- eti(xdf, ci = ci, verbose = verbose, ...)
+  dat <- .append_datagrid(dat, x, long = length(ci) > 1L)
   attr(dat, "object_name") <- insight::safe_deparse_symbol(substitute(x))
   dat
 }
@@ -183,6 +201,20 @@ eti.emmGrid <- function(x, ci = 0.95, verbose = TRUE, ...) {
 #' @export
 eti.emm_list <- eti.emmGrid
 
+#' @export
+eti.slopes <- function(x, ci = 0.95, verbose = TRUE, ...) {
+  xrvar <- .get_marginaleffects_draws(x)
+  dat <- eti(xrvar, ci = ci, verbose = verbose, ...)
+  dat <- .append_datagrid(dat, x, long = length(ci) > 1L)
+  attr(dat, "object_name") <- insight::safe_deparse_symbol(substitute(x))
+  dat
+}
+
+#' @export
+eti.comparisons <- eti.slopes
+
+#' @export
+eti.predictions <- eti.slopes
 
 #' @rdname eti
 #' @export
@@ -284,8 +316,8 @@ eti.get_predicted <- function(x, ci = 0.95, use_iterations = FALSE, verbose = TR
   ))
 
   data.frame(
-    "CI" = ci,
-    "CI_low" = results[1],
-    "CI_high" = results[2]
+    CI = ci,
+    CI_low = results[1],
+    CI_high = results[2]
   )
 }
