@@ -160,9 +160,7 @@ si.blavaan <- si.stanreg
 #' @export
 si.emmGrid <- function(posterior, prior = NULL,
                        BF = 1, verbose = TRUE, ...) {
-  samps <- .clean_priors_and_posteriors(posterior, prior,
-    verbose = verbose
-  )
+  samps <- .clean_priors_and_posteriors(posterior, prior, verbose = verbose)
 
   # Get SIs
   out <- si.data.frame(
@@ -170,6 +168,7 @@ si.emmGrid <- function(posterior, prior = NULL,
     BF = BF, verbose = verbose, ...
   )
 
+  out <- .append_datagrid(out, posterior, long = length(BF) > 1L)
   attr(out, "ci_method") <- "SI"
   attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(posterior))
   out
@@ -178,6 +177,15 @@ si.emmGrid <- function(posterior, prior = NULL,
 #' @export
 si.emm_list <- si.emmGrid
 
+#' @export
+si.slopes <- si.emmGrid
+
+#' @export
+si.comparisons <- si.emmGrid
+
+#' @export
+si.predictions <- si.emmGrid
+
 
 #' @export
 si.stanfit <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, effects = c("fixed", "random", "all"), ...) {
@@ -213,8 +221,27 @@ si.get_predicted <- function(posterior, prior = NULL, BF = 1, use_iterations = F
 
 
 #' @rdname si
+#' @inheritParams p_direction
 #' @export
-si.data.frame <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...) {
+si.data.frame <- function(posterior, prior = NULL, BF = 1, rvar_col = NULL, verbose = TRUE, ...) {
+  x_rvar <- .possibly_extract_rvar_col(posterior, rvar_col)
+  if (length(x_rvar) > 0L) {
+    cl <- match.call()
+    cl[[1]] <- bayestestR::si
+    cl$posterior <- x_rvar
+    cl$rvar_col <- NULL
+    prior_rvar <- .possibly_extract_rvar_col(posterior, prior)
+    if (length(prior_rvar) > 0L) {
+      cl$prior <- prior_rvar
+    }
+    out <- eval.parent(cl)
+
+    obj_name <- insight::safe_deparse_symbol(substitute(posterior))
+    attr(out, "object_name") <- sprintf('%s[["%s"]]', obj_name, rvar_col)
+
+    return(.append_datagrid(out, posterior, long = length(BF) > 1L))
+  }
+
   if (is.null(prior)) {
     prior <- posterior
     insight::format_warning(
@@ -247,7 +274,10 @@ si.data.frame <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...)
 
 #' @export
 si.draws <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...) {
-  si(.posterior_draws_to_df(posterior), prior = prior, BF = BF, verbose = verbose, ...)
+  si(.posterior_draws_to_df(posterior),
+    prior = if (!is.null(prior)) .posterior_draws_to_df(prior),
+    BF = BF, verbose = verbose, ...
+  )
 }
 
 #' @export
@@ -268,7 +298,7 @@ si.rvar <- si.draws
     )
   }
 
-  out <- data.frame(
+  data.frame(
     Parameter = colnames(posterior),
     CI = BF,
     CI_low = sis[, 1],
@@ -302,12 +332,12 @@ si.rvar <- si.draws
 
   f_prior <- .logspline(prior, ...)
   f_posterior <- .logspline(posterior, ...)
-  d_prior <- logspline::dlogspline(x_axis, f_prior)
-  d_posterior <- logspline::dlogspline(x_axis, f_posterior)
+  d_prior <- logspline::dlogspline(x_axis, f_prior, log = TRUE)
+  d_posterior <- logspline::dlogspline(x_axis, f_posterior, log = TRUE)
 
-  relative_d <- d_posterior / d_prior
+  relative_d <- d_posterior - d_prior
 
-  crit <- relative_d >= BF
+  crit <- relative_d >= log(BF)
 
   cp <- rle(stats::na.omit(crit))
   if (length(cp$lengths) > 3 && verbose) {
